==> aTunes_1.9.0.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/handlers/HotkeyHandler.java <==
/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.handlers;

import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;
import java.util.HashMap;
import java.util.Map;

import net.sourceforge.atunes.kernel.ControllerProxy;
import net.sourceforge.atunes.utils.LanguageTool;
import net.sourceforge.atunes.utils.log4j.LogCategories;
import net.sourceforge.atunes.utils.log4j.Logger;

import com.melloware.jintellitype.HotkeyListener;
import com.melloware.jintellitype.IntellitypeListener;
import com.melloware.jintellitype.JIntellitype;
import com.melloware.jintellitype.JIntellitypeConstants;

/**
 * Handler for global hotkeys and Intellitype keys.
 */
public class HotkeyHandler implements HotkeyListener, IntellitypeListener {

	/** The instance. */
	private static HotkeyHandler instance = new HotkeyHandler();

	/** The logger. */
	private static Logger logger = new Logger();

	/** The Constant RIGHT_ARROW. */
	private static final int RIGHT_ARROW = 39;

	/** The Constant LEFT_ARROW. */
	private static final int LEFT_ARROW = 37;

	/** The Constant UP_ARROW. */
	private static final int UP_ARROW = 38;

	/** The Constant DOWN_ARROW. */
	private static final int DOWN_ARROW = 40;

	/** The Constant CTRL_ALT_RIGHT. */
	private static final int CTRL_ALT_RIGHT = 1;

	/** The Constant CTRL_ALT_LEFT. */
	private static final int CTRL_ALT_LEFT = 2;

	/** The Constant CTRL_ALT_UP. */
	private static final int CTRL_ALT_UP = 3;

	/** The Constant CTRL_ALT_DOWN. */
	private static final int CTRL_ALT_DOWN = 4;

	/** The Constant CTRL_ALT_P. */
	private static final int CTRL_ALT_P = 5;

	/** The Constant CTRL_ALT_S. */
	private static final int CTRL_ALT_S = 6;

	/** The Constant CTRL_ALT_W. */
	private static final int CTRL_ALT_W = 7;

	/** The Constant CTRL_ALT_M. */
	private static final int CTRL_ALT_M = 8;

	/** The Constant CTRL_ALT_I. */
	private static final int CTRL_ALT_I = 9;

	/** The supported. */
	private static boolean supported;
	static {
		try {
			supported = JIntellitype.isJIntellitypeSupported();
		} catch (Throwable e) {
			supported = false;
			logger.debug(LogCategories.HANDLER, "JIntellitype is not supported");
		}
	}

	/** The enabled. */
	private boolean enabled;

	/** The hotkey description. */
	private Map<Integer, String[]> hotkeyDescription = new HashMap<Integer, String[]>();

	/**
	 * Instantiates a new hotkey handler.
	 */
	private HotkeyHandler() {
		// Nothing to do
	}

	/**
	 * Checks if hotkeys and Intellitype are supported.
	 * 
	 * @return if hotkeys and Intellitype are supported
	 */
	public static boolean areHotkeysAndIntellitypeSupported() {
		return supported;
	}

	/**
	 * Gets the single instance of HotkeyHandler.
	 * 
	 * @return single instance of HotkeyHandler
	 */
	public static HotkeyHandler getInstance() {
		return instance;
	}

	/**
	 * Enables or disables hotkeys.
	 * 
	 * @param enable
	 *            if hotkeys should be enabled
	 */
	public void enableHotkeys(boolean enable) {
		if (!areHotkeysAndIntellitypeSupported()) {
			return;
		}
		if (enable && !enabled) {
			// Next
			registerHotkey(CTRL_ALT_RIGHT, InputEvent.CTRL_DOWN_MASK + InputEvent.ALT_DOWN_MASK, RIGHT_ARROW, LanguageTool.getString("NEXT"));
			// Previous
			registerHotkey(CTRL_ALT_LEFT, InputEvent.CTRL_DOWN_MASK + InputEvent.ALT_DOWN_MASK, LEFT_ARROW, LanguageTool.getString("PREVIOUS"));
			//Volume up
			registerHotkey(CTRL_ALT_UP, InputEvent.CTRL_DOWN_MASK + InputEvent.ALT_DOWN_MASK, UP_ARROW, LanguageTool.getString("VOLUME_UP"));
			// Volume down
			registerHotkey(CTRL_ALT_DOWN, InputEvent.CTRL_DOWN_MASK + InputEvent.ALT_DOWN_MASK, DOWN_ARROW, LanguageTool.getString("VOLUME_DOWN"));
			// Play
			registerHotkey(CTRL_ALT_P, InputEvent.CTRL_DOWN_MASK + InputEvent.ALT_DOWN_MASK, 'P', LanguageTool.getString("PAUSE"));
			// Stop
			registerHotkey(CTRL_ALT_S, InputEvent.CTRL_DOWN_MASK + InputEvent.ALT_DOWN_MASK, 'S', LanguageTool.getString("STOP"));
			// Toggle window visibility
			registerHotkey(CTRL_ALT_W, InputEvent.CTRL_DOWN_MASK + InputEvent.ALT_DOWN_MASK, 'W', LanguageTool.getString("TOGGLE_WINDOW_VISIBILITY"));
			// Mute
			registerHotkey(CTRL_ALT_M, InputEvent.CTRL_DOWN_MASK + InputEvent.ALT_DOWN_MASK, 'M', LanguageTool.getString("MUTE"));
			// Show Osd info
			registerHotkey(CTRL_ALT_I, InputEvent.CTRL_DOWN_MASK + InputEvent.ALT_DOWN_MASK, 'I', LanguageTool.getString("SHOW_OSD"));

			JIntellitype.getInstance().addHotKeyListener(this);
			JIntellitype.getInstance().addIntellitypeListener(this);
			enabled = true;
		}
		if (!enable && enabled) {
			unregisterHotkey(CTRL_ALT_RIGHT);
			unregisterHotkey(CTRL_ALT_LEFT);
			unregisterHotkey(CTRL_ALT_UP);
			unregisterHotkey(CTRL_ALT_DOWN);
			unregisterHotkey(CTRL_ALT_P);
			unregisterHotkey(CTRL_ALT_S);
			unregisterHotkey(CTRL_ALT_W);
			unregisterHotkey(CTRL_ALT_M);
			unregisterHotkey(CTRL_ALT_I);
			JIntellitype.getInstance().removeHotKeyListener(this);
			JIntellitype.getInstance().removeIntellitypeListener(this);
			enabled = false;
		}
	}

	/**
	 * Release JIntellitype ressources.
	 */
	public void finish() {
		if (!areHotkeysAndIntellitypeSupported()) {
			return;
		}
		JIntellitype.getInstance().cleanUp();
	}

	/**
	 * Returns an array with hotkeys and their descrption.
	 * 
	 * @return an array with hotkeys and their descrption
	 */
	public String[][] getHotkeyDescription() {
		String[][] d = new String[hotkeyDescription.size()][];
		int i = 0;
		for (Integer key : hotkeyDescription.keySet()) {
			d[i++] = hotkeyDescription.get(key);
		}
		return d;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.melloware.jintellitype.HotkeyListener#onHotKey(int)
	 */
	@Override
	public void onHotKey(final int id) {
		logger.debug(LogCategories.HANDLER, "Hotkey " + id);
		switch (id) {
		case CTRL_ALT_RIGHT: {
			PlayerHandler.getInstance().next(false);
			break;
		}
		case CTRL_ALT_LEFT: {
			PlayerHandler.getInstance().previous();
			break;
		}
		case CTRL_ALT_UP: {
			PlayerHandler.getInstance().volumeUp();
			break;
		}
		case CTRL_ALT_DOWN: {
			PlayerHandler.getInstance().volumeDown();
			break;
		}
		case CTRL_ALT_P: {
			PlayerHandler.getInstance().play(true);
			break;
		}
		case CTRL_ALT_S: {
			PlayerHandler.getInstance().stop(true);
			break;
		}
		case CTRL_ALT_W: {
			VisualHandler.getInstance().toggleWindowVisibility();
			break;
		}
		case CTRL_ALT_M: {
			ControllerProxy.getInstance().getPlayerControlsController().setMute(!PlayerHandler.getInstance().isMute());
			SystemTrayHandler.getInstance().setMute(!PlayerHandler.getInstance().isMute());
			PlayerHandler.getInstance().setMute(!PlayerHandler.getInstance().isMute());
			break;
		}
		case CTRL_ALT_I: {
			VisualHandler.getInstance().showOSDDialog();
			break;
		}
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.melloware.jintellitype.IntellitypeListener#onIntellitype(int)
	 */
	@Override
	public void onIntellitype(final int command) {
		logger.debug(LogCategories.HANDLER, "Intellitype command " + command);
		switch (command) {
		case JIntellitypeConstants.APPCOMMAND_MEDIA_NEXTTRACK: {
			PlayerHandler.getInstance().next(false);
			break;
		}
		case JIntellitypeConstants.APPCOMMAND_MEDIA_PREVIOUSTRACK: {
			PlayerHandler.getInstance().previous();
			break;
		}
		case JIntellitypeConstants.APPCOMMAND_MEDIA_PLAY_PAUSE: {
			PlayerHandler.getInstance().play(true);
			break;
		}
		case JIntellitypeConstants.APPCOMMAND_MEDIA_STOP: {
			PlayerHandler.getInstance().stop(true);
			break;
		}
		case JIntellitypeConstants.APPCOMMAND_VOLUME_UP: {
			PlayerHandler.getInstance().volumeUp();
			break;
		}
		case JIntellitypeConstants.APPCOMMAND_VOLUME_DOWN: {
			PlayerHandler.getInstance().volumeDown();
			break;
		}
		case JIntellitypeConstants.APPCOMMAND_VOLUME_MUTE: {
			ControllerProxy.getInstance().getPlayerControlsController().setMute(!PlayerHandler.getInstance().isMute());
			SystemTrayHandler.getInstance().setMute(!PlayerHandler.getInstance().isMute());
			PlayerHandler.getInstance().setMute(!PlayerHandler.getInstance().isMute());
			break;
		}
		}
	}

	/**
	 * Register hotkey.
	 * 
	 * @param id
	 *            the id
	 * @param mod
	 *            the mod
	 * @param key
	 *            the key
	 * @param description
	 *            the description
	 */
	@SuppressWarnings("boxing")
	private void registerHotkey(int id, int mod, int key, String description) {
		JIntellitype.getInstance().registerSwingHotKey(id, mod, key);
		hotkeyDescription.put(id, new String[] { InputEvent.getModifiersExText(mod) + "+" + KeyEvent.getKeyText(key), description });
	}

	/**
	 * Unregister hotkey.
	 * 
	 * @param id
	 *            the id
	 */
	@SuppressWarnings("boxing")
	private void unregisterHotkey(int id) {
		JIntellitype.getInstance().unregisterHotKey(id);
		hotkeyDescription.remove(id);
	}
}

==> aTunes_1.10.1.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/handlers/HotkeyHandler.java <==
/*
 * aTunes 1.10.1
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.handlers;

import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;
import java.util.HashMap;
import java.util.Map;

import net.sourceforge.atunes.kernel.ApplicationFinishListener;
import net.sourceforge.atunes.kernel.ControllerProxy;
import net.sourceforge.atunes.kernel.Kernel;
import net.sourceforge.atunes.utils.LanguageTool;
import net.sourceforge.atunes.utils.log4j.LogCategories;
import net.sourceforge.atunes.utils.log4j.Logger;

import com.melloware.jintellitype.HotkeyListener;
import com.melloware.jintellitype.IntellitypeListener;
import com.melloware.jintellitype.JIntellitype;
import com.melloware.jintellitype.JIntellitypeConstants;

/**
 * Handler for global hotkeys and Intellitype keys.
 */
public class HotkeyHandler implements HotkeyListener, IntellitypeListener, ApplicationFinishListener {

	/** The instance. */
	private static HotkeyHandler instance = new HotkeyHandler();

	/** The logger. */
	private static Logger logger = new Logger();

	/** The Constant RIGHT_ARROW. */
	private static final int RIGHT_ARROW = 39;

	/** The Constant LEFT_ARROW. */
	private static final int LEFT_ARROW = 37;

	/** The Constant UP_ARROW. */
	private static final int UP_ARROW = 38;

	/** The Constant DOWN_ARROW. */
	private static final int DOWN_ARROW = 40;

	/** The Constant CTRL_ALT_RIGHT. */
	private static final int CTRL_ALT_RIGHT = 1;

	/** The Constant CTRL_ALT_LEFT. */
	private static final int CTRL_ALT_LEFT = 2;

	/** The Constant CTRL_ALT_UP. */
	private static final int CTRL_ALT_UP = 3;

	/** The Constant CTRL_ALT_DOWN. */
	private static final int CTRL_ALT_DOWN = 4;

	/** The Constant CTRL_ALT_P. */
	private static final int CTRL_ALT_P = 5;

	/** The Constant CTRL_ALT_S. */
	private static final int CTRL_ALT_S = 6;

	/** The Constant CTRL_ALT_W. */
	private static final int CTRL_ALT_W = 7;

	/** The Constant CTRL_ALT_M. */
	private static final int CTRL_ALT_M = 8;

	/** The Constant CTRL_ALT_I. */
	private static final int CTRL_ALT_I = 9;

	/** The supported. */
	private static boolean supported;

	/** The enabled. */
	private boolean enabled;

	private static class Hotkey {

		private int id;
		private int mod;
		private int key;
		private String description;
		
		public Hotkey(int id, int mod, int key, String description) {
			this.id = id;
			this.mod = mod;
			this.key = key;
			this.description = description;
		}

		/**
		 * @return the id
		 */
		public int getId() {
			return id;
		}

		/**
		 * @return the mod
		 */
		public int getMod() {
			return mod;
		}

		/**
		 * @return the key
		 */
		public int getKey() {
			return key;
		}

		/**
		 * @return the description
		 */
		public String getDescription() {
			return description;
		}
	}
	
	private static Map<Integer, Hotkey> hotkeysMap;
	
	static {
		try {
			supported = JIntellitype.isJIntellitypeSupported();
			
			// Create Hotkey objects
			hotkeysMap = new HashMap<Integer, Hotkey>();
			hotkeysMap.put(CTRL_ALT_RIGHT, new Hotkey(CTRL_ALT_RIGHT, InputEvent.CTRL_DOWN_MASK + InputEvent.ALT_DOWN_MASK, RIGHT_ARROW, LanguageTool.getString("NEXT")));
			hotkeysMap.put(CTRL_ALT_LEFT, new Hotkey(CTRL_ALT_LEFT, InputEvent.CTRL_DOWN_MASK + InputEvent.ALT_DOWN_MASK, LEFT_ARROW, LanguageTool.getString("PREVIOUS")));
			hotkeysMap.put(CTRL_ALT_UP, new Hotkey(CTRL_ALT_UP, InputEvent.CTRL_DOWN_MASK + InputEvent.ALT_DOWN_MASK, UP_ARROW, LanguageTool.getString("VOLUME_UP")));
			hotkeysMap.put(CTRL_ALT_DOWN, new Hotkey(CTRL_ALT_DOWN, InputEvent.CTRL_DOWN_MASK + InputEvent.ALT_DOWN_MASK, DOWN_ARROW, LanguageTool.getString("VOLUME_DOWN")));
			hotkeysMap.put(CTRL_ALT_P, new Hotkey(CTRL_ALT_P, InputEvent.CTRL_DOWN_MASK + InputEvent.ALT_DOWN_MASK, 'P', LanguageTool.getString("PAUSE")));
			hotkeysMap.put(CTRL_ALT_S, new Hotkey(CTRL_ALT_S, InputEvent.CTRL_DOWN_MASK + InputEvent.ALT_DOWN_MASK, 'S', LanguageTool.getString("STOP")));
			hotkeysMap.put(CTRL_ALT_W, new Hotkey(CTRL_ALT_W, InputEvent.CTRL_DOWN_MASK + InputEvent.ALT_DOWN_MASK, 'W', LanguageTool.getString("TOGGLE_WINDOW_VISIBILITY")));
			hotkeysMap.put(CTRL_ALT_M, new Hotkey(CTRL_ALT_M, InputEvent.CTRL_DOWN_MASK + InputEvent.ALT_DOWN_MASK, 'M', LanguageTool.getString("MUTE")));
			hotkeysMap.put(CTRL_ALT_I, new Hotkey(CTRL_ALT_I, InputEvent.CTRL_DOWN_MASK + InputEvent.ALT_DOWN_MASK, 'I', LanguageTool.getString("SHOW_OSD")));
		} catch (Throwable e) {
			supported = false;
			logger.debug(LogCategories.HANDLER, "JIntellitype is not supported");
		}
	}

	
	
	
	/**
	 * Instantiates a new hotkey handler.
	 */
	private HotkeyHandler() {
		Kernel.getInstance().addFinishListener(this);
	}

	/**
	 * Checks if hotkeys and Intellitype are supported.
	 * 
	 * @return if hotkeys and Intellitype are supported
	 */
	public static boolean areHotkeysAndIntellitypeSupported() {
		return supported;
	}

	/**
	 * Gets the single instance of HotkeyHandler.
	 * 
	 * @return single instance of HotkeyHandler
	 */
	public static HotkeyHandler getInstance() {
		return instance;
	}

	/**
	 * Enables or disables hotkeys.
	 * 
	 * @param enable
	 *            if hotkeys should be enabled
	 */
	public void enableHotkeys(boolean enable) {
		if (!areHotkeysAndIntellitypeSupported()) {
			return;
		}
		if (enable && !enabled) {
			// Next
			registerHotkey(CTRL_ALT_RIGHT);
			// Previous
			registerHotkey(CTRL_ALT_LEFT);
			//Volume up
			registerHotkey(CTRL_ALT_UP);
			// Volume down
			registerHotkey(CTRL_ALT_DOWN);
			// Play
			registerHotkey(CTRL_ALT_P);
			// Stop
			registerHotkey(CTRL_ALT_S);
			// Toggle window visibility
			registerHotkey(CTRL_ALT_W);
			// Mute
			registerHotkey(CTRL_ALT_M);
			// Show Osd info
			registerHotkey(CTRL_ALT_I);

			JIntellitype.getInstance().addHotKeyListener(this);
			JIntellitype.getInstance().addIntellitypeListener(this);
			enabled = true;
		}
		if (!enable && enabled) {
			unregisterHotkey(CTRL_ALT_RIGHT);
			unregisterHotkey(CTRL_ALT_LEFT);
			unregisterHotkey(CTRL_ALT_UP);
			unregisterHotkey(CTRL_ALT_DOWN);
			unregisterHotkey(CTRL_ALT_P);
			unregisterHotkey(CTRL_ALT_S);
			unregisterHotkey(CTRL_ALT_W);
			unregisterHotkey(CTRL_ALT_M);
			unregisterHotkey(CTRL_ALT_I);
			JIntellitype.getInstance().removeHotKeyListener(this);
			JIntellitype.getInstance().removeIntellitypeListener(this);
			enabled = false;
		}
	}

	/**
	 * Release JIntellitype ressources.
	 */
	public void applicationFinish() {
		if (!areHotkeysAndIntellitypeSupported()) {
			return;
		}
		JIntellitype.getInstance().cleanUp();
	}

	/**
	 * Returns an array with hotkeys and their descrption.
	 * 
	 * @return an array with hotkeys and their descrption
	 */
	public String[][] getHotkeyDescription() {
		String[][] d = new String[hotkeysMap.size()][];
		int i = 0;
		for (Integer key : hotkeysMap.keySet()) {
			d[i++] = new String[] { InputEvent.getModifiersExText(hotkeysMap.get(key).getMod()) + "+" + KeyEvent.getKeyText(hotkeysMap.get(key).getKey()), hotkeysMap.get(key).getDescription() };
		}
		return d;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.melloware.jintellitype.HotkeyListener#onHotKey(int)
	 */
	@Override
	public void onHotKey(final int id) {
		logger.debug(LogCategories.HANDLER, "Hotkey " + id);
		switch (id) {
		case CTRL_ALT_RIGHT: {
			PlayerHandler.getInstance().playNextAudioObject(false);
			break;
		}
		case CTRL_ALT_LEFT: {
			PlayerHandler.getInstance().playPreviousAudioObject();
			break;
		}
		case CTRL_ALT_UP: {
			PlayerHandler.getInstance().volumeUp();
			break;
		}
		case CTRL_ALT_DOWN: {
			PlayerHandler.getInstance().volumeDown();
			break;
		}
		case CTRL_ALT_P: {
			PlayerHandler.getInstance().playCurrentAudioObject(true);
			break;
		}
		case CTRL_ALT_S: {
			PlayerHandler.getInstance().stopCurrentAudioObject(true);
			break;
		}
		case CTRL_ALT_W: {
			VisualHandler.getInstance().toggleWindowVisibility();
			break;
		}
		case CTRL_ALT_M: {
			ControllerProxy.getInstance().getPlayerControlsController().setMute(!Kernel.getInstance().state.isMuteEnabled());
			SystemTrayHandler.getInstance().setMute(!Kernel.getInstance().state.isMuteEnabled());
			PlayerHandler.getInstance().applyMuteState(!Kernel.getInstance().state.isMuteEnabled());
			break;
		}
		case CTRL_ALT_I: {
			VisualHandler.getInstance().showOSDDialog();
			break;
		}
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.melloware.jintellitype.IntellitypeListener#onIntellitype(int)
	 */
	@Override
	public void onIntellitype(final int command) {
		logger.debug(LogCategories.HANDLER, "Intellitype command " + command);
		switch (command) {
		case JIntellitypeConstants.APPCOMMAND_MEDIA_NEXTTRACK: {
			PlayerHandler.getInstance().playNextAudioObject(false);
			break;
		}
		case JIntellitypeConstants.APPCOMMAND_MEDIA_PREVIOUSTRACK: {
			PlayerHandler.getInstance().playPreviousAudioObject();
			break;
		}
		case JIntellitypeConstants.APPCOMMAND_MEDIA_PLAY_PAUSE: {
			PlayerHandler.getInstance().playCurrentAudioObject(true);
			break;
		}
		case JIntellitypeConstants.APPCOMMAND_MEDIA_STOP: {
			PlayerHandler.getInstance().stopCurrentAudioObject(true);
			break;
		}
		case JIntellitypeConstants.APPCOMMAND_VOLUME_UP: {
			PlayerHandler.getInstance().volumeUp();
			break;
		}
		case JIntellitypeConstants.APPCOMMAND_VOLUME_DOWN: {
			PlayerHandler.getInstance().volumeDown();
			break;
		}
		case JIntellitypeConstants.APPCOMMAND_VOLUME_MUTE: {
			ControllerProxy.getInstance().getPlayerControlsController().setMute(!Kernel.getInstance().state.isMuteEnabled());
			SystemTrayHandler.getInstance().setMute(!Kernel.getInstance().state.isMuteEnabled());
			PlayerHandler.getInstance().applyMuteState(!Kernel.getInstance().state.isMuteEnabled());
			break;
		}
		}
	}

	/**
	 * Register hotkey.
	 * 
	 * @param id
	 *            the id
	 * @param mod
	 *            the mod
	 * @param key
	 *            the key
	 * @param description
	 *            the description
	 */

	private void registerHotkey(int id) {
		Hotkey hotkey = hotkeysMap.get(id);
		JIntellitype.getInstance().registerSwingHotKey(hotkey.getId(), hotkey.getMod(), hotkey.getKey());
	}

	/**
	 * Unregister hotkey.
	 * 
	 * @param id
	 *            the id
	 */

	private void unregisterHotkey(int id) {
		JIntellitype.getInstance().unregisterHotKey(id);
	}
}
